@@ -1,9 +1,9 @@
 from jsonpath_ng import parse
-from paginate import ec2_paginate as paginate
+import ec2_paginate
 
 #####################################
 
-class ec2_describe_instances(paginate):
+class describe_instances(ec2_paginate):
     def name(self): return __class__.__name__        
     def jsonpath_expression(self): return parse('Reservations[*].Instances[*]')
 
