@@ -40,16 +40,9 @@ class paginate():
 
 class ec2_paginate(paginate):
     def __init__(self, session, **kargs):
-        kargs.update({'ep':'_'.join(self.name().split('_')[1:])})
+        kargs.update({'ep':self.name()})
         kargs.update({'service':'ec2'})
         paginate.__init__(self, session, **kargs)
 
 #####################################
 #####################################
-
-class ec2_describe_instances(ec2_paginate):
-    def name(self): return __class__.__name__        
-    def jsonpath_expression(self): return parse('Reservations[*].Instances[*]')
-
-#####################################
-#####################################
